==> qttranslations-opensource-src_5.2.1.orig.tar.xz: qttranslations-opensource-src-5.2.1/translations/qt_help_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>QCLuceneResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Výsledky hledání</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Poznámka:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed!</source>
        <translation>Nemusí být ukázány všechny výsledky, protože dokumentace je stále ještě rejstříkována!</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Nebyly nalezeny žádné dokumenty, které by odpovídaly vašemu hledání.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Důvodem pro to by mohlo být, že dokumentace je stále ještě rejstříkována.)</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &apos;%1&apos; is not set up yet!</source>
        <translation>Soubor se sbírkou &apos;%1&apos; ještě není zřízen!</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Databázový ovladač pro SQLite nelze nahrát!</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Nelze otevřít soubor se sbírkou: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1!</source>
        <translation>V souboru %1 nelze vytvořit žádné tabulky!</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; already exists!</source>
        <translation>Soubor se sbírkou &apos;%1&apos; již existuje!</translation>
    </message>
    <message>
        <source>Unknown filter &apos;%1&apos;!</source>
        <translation>Neznámý filtr &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Invalid documentation file &apos;%1&apos;!</source>
        <translation>Neplatný soubor s dokumentací &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Cannot register namespace &apos;%1&apos;!</source>
        <translation>Nelze zapsat jmenný prostor %1!</translation>
    </message>
    <message>
        <source>Cannot open database &apos;%1&apos; to optimize!</source>
        <translation>Databázi &apos;%1&apos; nelze otevřít pro vyladění!</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Nelze vytvořit adresář: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Nelze kopírovat soubor se sbírkou: %1</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Nelze zapsat filtr %1!</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1!</source>
        <translation>Nelze otevřít soubor s dokumentací: %1!</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered!</source>
        <translation>Jmenný prostor %1 nebyl zapsán!</translation>
    </message>
    <message>
        <source>Namespace %1 already exists!</source>
        <translation>Jmenný prostor %1 již existuje!</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &apos;%1&apos; &apos;%2&apos;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Databázi nelze otevřít: &apos;%1&apos; &apos;%2&apos;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpEngineCore</name>
    <message>
        <source>Cannot open documentation file %1: %2!</source>
        <translation>Nelze otevřít soubor s dokumentací %1: %2!</translation>
    </message>
    <message>
        <source>The specified namespace does not exist!</source>
        <translation>Zadaný jmenný prostor neexistuje!</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Invalid help data!</source>
        <translation>Neplatná data s nápovědou!</translation>
    </message>
    <message>
        <source>No output file name specified!</source>
        <translation>Pro výstupní soubor nebyl zadán žádný název!</translation>
    </message>
    <message>
        <source>Building up file structure...</source>
        <translation>Vytváří se uspořádání souboru...</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten!</source>
        <translation>Soubor %1 nelze přepsat!</translation>
    </message>
    <message>
        <source>Cannot open data base file %1!</source>
        <translation>Nelze otevřít soubor s databází: %1!</translation>
    </message>
    <message>
        <source>Cannot register namespace %1!</source>
        <translation>Nelze zapsat jmenný prostor %1!</translation>
    </message>
    <message>
        <source>Insert custom filters...</source>
        <translation>Vložit uživatelsky stanovené filtry...</translation>
    </message>
    <message>
        <source>Insert help data for filter section (%1 of %2)...</source>
        <translation>Vložit data s nápovědou pro oddělení s filtrem (%1 von %2) einfügen...</translation>
    </message>
    <message>
        <source>Documentation successfully generated.</source>
        <translation>Dokumentace byla úspěšně vytvořena.</translation>
    </message>
    <message>
        <source>Some tables already exist!</source>
        <translation>Některé tabulky již existují!</translation>
    </message>
    <message>
        <source>Cannot create tables!</source>
        <translation>Tabulky nelze vytvořit!</translation>
    </message>
    <message>
        <source>Cannot register virtual folder!</source>
        <translation>Virtuální adresář nelze zapsat!</translation>
    </message>
    <message>
        <source>Insert files...</source>
        <translation>Vložit soubory...</translation>
    </message>
    <message>
        <source>The referenced file %1 must be inside or within a subdirectory of (%2). Skipping it.</source>
        <translation>Odkazovaný soubor %1 se musí nacházet v adresáři %2 nebo v jeho podadresáři. Přeskakuje se.</translation>
    </message>
    <message>
        <source>The file %1 does not exist! Skipping it.</source>
        <translation>Soubor %1 neexistuje! Přeskakuje se.</translation>
    </message>
    <message>
        <source>Cannot open file %1! Skipping it.</source>
        <translation>Soubor %1 nelze otevřít! Přeskakuje se.</translation>
    </message>
    <message>
        <source>The filter %1 is already registered!</source>
        <translation>Filtr %1 je již zapsán!</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Nelze zapsat filtr %1!</translation>
    </message>
    <message>
        <source>Insert indices...</source>
        <translation>Vložit rejstříky...</translation>
    </message>
    <message>
        <source>Insert contents...</source>
        <translation>Vložit obsah...</translation>
    </message>
    <message>
        <source>Cannot insert contents!</source>
        <translation>Obsah nelze vložit!</translation>
    </message>
    <message>
        <source>Cannot register contents!</source>
        <translation>Obsah nelze zapsat!</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; does not exist.</source>
        <translation>Soubor &apos;%1&apos; neexistuje.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; cannot be opened.</source>
        <translation>Soubor &apos;%1&apos; nelze otevřít.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; contains an invalid link to file &apos;%2&apos;</source>
        <translation>Soubor &apos;%1&apos; obsahuje neplatný odkaz na soubor &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Invalid links in HTML files.</source>
        <translation>Neplatné odkazy v souborech HTML.</translation>
    </message>
</context>
<context>
    <name>QHelpProject</name>
    <message>
        <source>Unknown token.</source>
        <translation>Neznámý symbol.</translation>
    </message>
    <message>
        <source>Unknown token. Expected &quot;QtHelpProject&quot;!</source>
        <translation>Neznámý symbol. Byl očekáván &quot;QtHelpProject&quot;!</translation>
    </message>
    <message>
        <source>Error in line %1: %2</source>
        <translation>Chyba na řádku %1: %2</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax.</source>
        <translation>Virtuální složka má neplatnou skladbu.</translation>
    </message>
    <message>
        <source>Namespace has invalid syntax.</source>
        <translation>Jmenný prostor má neplatnou skladbu.</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject.</source>
        <translation>Chybějící jmenný prostor QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject</source>
        <translation>Chybějící virtuální složka v QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing attribute in keyword at line %1.</source>
        <translation>Chybějící vlastnost v klíčovém slově na řádku %1.</translation>
    </message>
    <message>
        <source>The input file %1 could not be opened!</source>
        <translation>Vstupní soubor %1 se nepodařilo otevřít!</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Předchozí hledání</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Další hledání</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation>Rozšířené hledání</translation>
    </message>
    <message>
        <source>words &lt;B&gt;similar&lt;/B&gt; to:</source>
        <translation>Slova &lt;B&gt;podobná&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>&lt;B&gt;without&lt;/B&gt; the words:</source>
        <translation>&lt;B&gt;beze&lt;/B&gt; slov:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;exact phrase&lt;/B&gt;:</source>
        <translation>s &lt;B&gt;přesnou skupinou slov&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;all&lt;/B&gt; of the words:</source>
        <translation>se &lt;B&gt;všemi&lt;/B&gt; slovy:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;at least one&lt;/B&gt; of the words:</source>
        <translation>s &lt;B&gt;jakýmkoli&lt;/B&gt; ze slov:</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 - jeden zásah</numerusform>
            <numerusform>%1 - %2 ze %n zásahů</numerusform>
            <numerusform>%1 - %2 z %n zásahů</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 z 0 zásahů</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.5.1.orig.tar.xz: qttranslations-opensource-src-5.5.1/translations/qt_help_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>QCLuceneResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Výsledky hledání</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Poznámka:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed!</source>
        <translation>Nemusí být ukázány všechny výsledky, protože dokumentace je stále ještě rejstříkována!</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Nebyly nalezeny žádné dokumenty, které by odpovídaly vašemu hledání.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Důvodem pro to by mohlo být, že dokumentace je stále ještě rejstříkována.)</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &apos;%1&apos; is not set up yet!</source>
        <translation>Soubor se sbírkou &apos;%1&apos; ještě není zřízen!</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Databázový ovladač pro SQLite nelze nahrát!</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Nelze otevřít soubor se sbírkou: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1!</source>
        <translation>V souboru %1 nelze vytvořit žádné tabulky!</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; already exists!</source>
        <translation>Soubor se sbírkou &apos;%1&apos; již existuje!</translation>
    </message>
    <message>
        <source>Unknown filter &apos;%1&apos;!</source>
        <translation>Neznámý filtr &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Invalid documentation file &apos;%1&apos;!</source>
        <translation>Neplatný soubor s dokumentací &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Cannot register namespace &apos;%1&apos;!</source>
        <translation>Nelze zapsat jmenný prostor %1!</translation>
    </message>
    <message>
        <source>Cannot open database &apos;%1&apos; to optimize!</source>
        <translation>Databázi &apos;%1&apos; nelze otevřít pro vyladění!</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Nelze vytvořit adresář: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Nelze kopírovat soubor se sbírkou: %1</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Nelze zapsat filtr %1!</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1!</source>
        <translation>Nelze otevřít soubor s dokumentací: %1!</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered!</source>
        <translation>Jmenný prostor %1 nebyl zapsán!</translation>
    </message>
    <message>
        <source>Namespace %1 already exists!</source>
        <translation>Jmenný prostor %1 již existuje!</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &apos;%1&apos; &apos;%2&apos;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Databázi nelze otevřít: &apos;%1&apos; &apos;%2&apos;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpEngineCore</name>
    <message>
        <source>Cannot open documentation file %1: %2!</source>
        <translation>Nelze otevřít soubor s dokumentací %1: %2!</translation>
    </message>
    <message>
        <source>The specified namespace does not exist!</source>
        <translation>Zadaný jmenný prostor neexistuje!</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Invalid help data!</source>
        <translation>Neplatná data s nápovědou!</translation>
    </message>
    <message>
        <source>No output file name specified!</source>
        <translation>Pro výstupní soubor nebyl zadán žádný název!</translation>
    </message>
    <message>
        <source>Building up file structure...</source>
        <translation>Vytváří se uspořádání souboru...</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten!</source>
        <translation>Soubor %1 nelze přepsat!</translation>
    </message>
    <message>
        <source>Cannot open data base file %1!</source>
        <translation>Nelze otevřít soubor s databází: %1!</translation>
    </message>
    <message>
        <source>Cannot register namespace %1!</source>
        <translation>Nelze zapsat jmenný prostor %1!</translation>
    </message>
    <message>
        <source>Insert custom filters...</source>
        <translation>Vložit uživatelsky stanovené filtry...</translation>
    </message>
    <message>
        <source>Insert help data for filter section (%1 of %2)...</source>
        <translation>Vložit data s nápovědou pro oddělení s filtrem (%1 von %2) einfügen...</translation>
    </message>
    <message>
        <source>Documentation successfully generated.</source>
        <translation>Dokumentace byla úspěšně vytvořena.</translation>
    </message>
    <message>
        <source>Some tables already exist!</source>
        <translation>Některé tabulky již existují!</translation>
    </message>
    <message>
        <source>Cannot create tables!</source>
        <translation>Tabulky nelze vytvořit!</translation>
    </message>
    <message>
        <source>Cannot register virtual folder!</source>
        <translation>Virtuální adresář nelze zapsat!</translation>
    </message>
    <message>
        <source>Insert files...</source>
        <translation>Vložit soubory...</translation>
    </message>
    <message>
        <source>The referenced file %1 must be inside or within a subdirectory of (%2). Skipping it.</source>
        <translation>Odkazovaný soubor %1 se musí nacházet v adresáři %2 nebo v jeho podadresáři. Přeskakuje se.</translation>
    </message>
    <message>
        <source>The file %1 does not exist! Skipping it.</source>
        <translation>Soubor %1 neexistuje! Přeskakuje se.</translation>
    </message>
    <message>
        <source>Cannot open file %1! Skipping it.</source>
        <translation>Soubor %1 nelze otevřít! Přeskakuje se.</translation>
    </message>
    <message>
        <source>The filter %1 is already registered!</source>
        <translation>Filtr %1 je již zapsán!</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Nelze zapsat filtr %1!</translation>
    </message>
    <message>
        <source>Insert indices...</source>
        <translation>Vložit rejstříky...</translation>
    </message>
    <message>
        <source>Insert contents...</source>
        <translation>Vložit obsah...</translation>
    </message>
    <message>
        <source>Cannot insert contents!</source>
        <translation>Obsah nelze vložit!</translation>
    </message>
    <message>
        <source>Cannot register contents!</source>
        <translation>Obsah nelze zapsat!</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; does not exist.</source>
        <translation>Soubor &apos;%1&apos; neexistuje.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; cannot be opened.</source>
        <translation>Soubor &apos;%1&apos; nelze otevřít.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; contains an invalid link to file &apos;%2&apos;</source>
        <translation>Soubor &apos;%1&apos; obsahuje neplatný odkaz na soubor &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Invalid links in HTML files.</source>
        <translation>Neplatné odkazy v souborech HTML.</translation>
    </message>
</context>
<context>
    <name>QHelpProject</name>
    <message>
        <source>Unknown token.</source>
        <translation>Neznámý symbol.</translation>
    </message>
    <message>
        <source>Unknown token in file &quot;%1&quot;.</source>
        <translation>Neznámý symbol v souboru &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Unknown token. Expected &quot;QtHelpProject&quot;!</source>
        <translation>Neznámý symbol. Byl očekáván &quot;QtHelpProject&quot;!</translation>
    </message>
    <message>
        <source>Error in line %1: %2</source>
        <translation>Chyba na řádku %1: %2</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax in file: &quot;%1&quot;</source>
        <translation>Virtuální složka má neplatný obsah v souboru: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Namespace &quot;%1&quot; has invalid syntax in file: &quot;%2&quot;</source>
        <translation>Jmenný prostor &quot;%1&quot; má neplatný obsah v souboru: &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject file: &quot;%1&quot;</source>
        <translation>Chybějící jmenný prostor v souboru QtHelpProject: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject file: &quot;%1&quot;</source>
        <translation>Chybějící virtuální složka v souboru QtHelpProject: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax.</source>
        <translation>Virtuální složka má neplatnou skladbu.</translation>
    </message>
    <message>
        <source>Namespace has invalid syntax.</source>
        <translation>Jmenný prostor má neplatnou skladbu.</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject.</source>
        <translation>Chybějící jmenný prostor QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject</source>
        <translation>Chybějící virtuální složka v QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing attribute in keyword at line %1.</source>
        <translation>Chybějící vlastnost v klíčovém slově na řádku %1.</translation>
    </message>
    <message>
        <source>The input file %1 could not be opened!</source>
        <translation>Vstupní soubor %1 se nepodařilo otevřít!</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Předchozí hledání</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Další hledání</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation>Rozšířené hledání</translation>
    </message>
    <message>
        <source>words &lt;B&gt;similar&lt;/B&gt; to:</source>
        <translation>Slova &lt;B&gt;podobná&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>&lt;B&gt;without&lt;/B&gt; the words:</source>
        <translation>&lt;B&gt;beze&lt;/B&gt; slov:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;exact phrase&lt;/B&gt;:</source>
        <translation>s &lt;B&gt;přesnou skupinou slov&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;all&lt;/B&gt; of the words:</source>
        <translation>se &lt;B&gt;všemi&lt;/B&gt; slovy:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;at least one&lt;/B&gt; of the words:</source>
        <translation>s &lt;B&gt;jakýmkoli&lt;/B&gt; ze slov:</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 - jeden zásah</numerusform>
            <numerusform>%1 - %2 ze %n zásahů</numerusform>
            <numerusform>%1 - %2 z %n zásahů</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 z 0 zásahů</translation>
    </message>
</context>
</TS>
